@@ -8,6 +8,10 @@ echo "" 												>> $EXTENSION/build_order.txt
 if [[ $INSTALL_RECOMMENDED != false ]]; then 
 	[[ $(command -v valac) == "" ]] && echo "Installing vala" && extension --install vala && echo "Finished vala"
 fi
+# Optional
+if [[ $INSTALL_OPTIONAL != false ]]; then 
+	[[ $(command -v gtkdocize) == "" ]] && echo "Installing gtk_doc" && extension --install gtk_doc && echo "Finished gtk_doc"
+fi
 
 if [ $BUILD_ALL == "false" ] && [[ $(command -v xfce4-kiosk-query) == "" ]]; then
 	echo "libxfce4util" 								>> $EXTENSION/build_order.txt
